@@ -9,11 +9,13 @@ import re
 
 from django.conf import settings
 from django.core.cache import cache
-from django.core.urlresolvers import Resolver404, resolve, reverse, NoReverseMatch
+from django.core.urlresolvers import (
+    Resolver404, resolve, reverse, NoReverseMatch)
 from django.db import models
 from django.db.models import signals
 from django.http import HttpResponse
 from django.utils.functional import curry as partial, lazy, wraps
+from django.utils.http import http_date
 from django.utils.safestring import mark_safe
 from django.utils.translation import get_language, ugettext_lazy as _
 
@@ -36,7 +38,7 @@ cycle_app_reverse_cache()
 
 
 def app_reverse(viewname, urlconf=None, args=None, kwargs=None, prefix=None,
-        *vargs, **vkwargs):
+                *vargs, **vkwargs):
     """
     Reverse URLs from application contents
 
@@ -94,7 +96,8 @@ def app_reverse(viewname, urlconf=None, args=None, kwargs=None, prefix=None,
     if url_prefix:
         # vargs and vkwargs are used to send through additional parameters
         # which are uninteresting to us (such as current_app)
-        return reverse(viewname,
+        return reverse(
+            viewname,
             url_prefix[0],
             args=args,
             kwargs=kwargs,
@@ -169,7 +172,8 @@ class ApplicationContent(models.Model):
                 "config": app_conf
             }
 
-        cls.add_to_class('urlconf_path',
+        cls.add_to_class(
+            'urlconf_path',
             models.CharField(_('application'), max_length=100, choices=[
                 (c['urls'], c['name']) for c in cls.ALL_APPS_CONFIG.values()])
         )
@@ -216,8 +220,9 @@ class ApplicationContent(models.Model):
                 m = super(ApplicationContentItemEditorForm, self).save(
                     commit=False, *args, **kwargs)
 
-                m.parameters = dict((k, self.cleaned_data[k]) for k
-                    in self.custom_fields if k in self.cleaned_data)
+                m.parameters = dict(
+                    (k, self.cleaned_data[k])
+                    for k in self.custom_fields if k in self.cleaned_data)
 
                 if commit:
                     m.save(**kwargs)
@@ -272,8 +277,11 @@ class ApplicationContent(models.Model):
 
         # Save the application configuration for reuse elsewhere
         request._feincms_extra_context.update({
-            'app_config': dict(self.app_config,
-                urlconf_path=self.urlconf_path)})
+            'app_config': dict(
+                self.app_config,
+                urlconf_path=self.urlconf_path,
+            ),
+        })
 
         view_wrapper = self.app_config.get("view_wrapper", None)
         if view_wrapper:
@@ -338,7 +346,6 @@ class ApplicationContent(models.Model):
         Combine all headers that were set by the different content types
         We are interested in Cache-Control, Last-Modified, Expires
         """
-        from django.utils.http import http_date
 
         # Ideally, for the Cache-Control header, we'd want to do some
         # intelligent combining, but that's hard. Let's just collect and unique
@@ -369,7 +376,7 @@ class ApplicationContent(models.Model):
         contents = cls.objects.filter(
             parent__in=page_class.objects.active(),
             urlconf_path=urlconf_path,
-            ).order_by('pk').select_related('parent')
+        ).order_by('pk').select_related('parent')
 
         if len(contents) > 1:
             try:
@@ -377,7 +384,7 @@ class ApplicationContent(models.Model):
                 return [
                     content for content in contents if
                     short_language_code(content.parent.language) == current
-                    ][0]
+                ][0]
 
             except (AttributeError, IndexError):
                 pass
