@@ -16,5 +16,6 @@ _cached_thumbnailer = None
 def admin_thumbnail(mediafile, dimensions='100x100'):
     global _cached_thumbnailer
     if not _cached_thumbnailer:
-        _cached_thumbnailer = get_object(settings.FEINCMS_MEDIALIBRARY_THUMBNAIL)
+        _cached_thumbnailer = get_object(
+            settings.FEINCMS_MEDIALIBRARY_THUMBNAIL)
     return _cached_thumbnailer(mediafile, dimensions=dimensions)
