@@ -8,10 +8,13 @@ import traceback
 
 from django import template
 from django.conf import settings
+from django.db.models.loading import get_model
 from django.http import HttpRequest
 
-from feincms.module.page.models import BasePage, Page
-from feincms.utils.templatetags import (SimpleNodeWithVarAndArgs,
+from feincms import settings as feincms_settings
+from feincms.module.page.extensions.navigation import PagePretender
+from feincms.utils.templatetags import (
+    SimpleNodeWithVarAndArgs,
     do_simple_node_with_var_and_args_helper,
     SimpleAssignmentNodeWithVarAndArgs,
     do_simple_assignment_node_with_var_and_args_helper)
@@ -22,6 +25,10 @@ logger = logging.getLogger('feincms.templatetags.page')
 register = template.Library()
 
 
+def _get_page_model():
+    return get_model(*feincms_settings.FEINCMS_DEFAULT_PAGE_MODEL.split('.'))
+
+
 # ------------------------------------------------------------------------
 # TODO: Belongs in some utility module
 def format_exception(e):
@@ -36,12 +43,13 @@ def feincms_nav(context, feincms_page, level=1, depth=1):
     Saves a list of pages into the given context variable.
     """
 
+    page_class = _get_page_model()
+
     if isinstance(feincms_page, HttpRequest):
         try:
-            # warning: explicit Page reference here
-            feincms_page = Page.objects.for_request(
+            feincms_page = page_class.objects.for_request(
                 feincms_page, best_match=True)
-        except Page.DoesNotExist:
+        except page_class.DoesNotExist:
             return []
 
     mptt_opts = feincms_page._mptt_meta
@@ -78,13 +86,13 @@ def feincms_nav(context, feincms_page, level=1, depth=1):
             # (or even deeper in the tree). If we would continue processing,
             # this would result in pages from different subtrees being
             # returned directly adjacent to each other.
-            queryset = Page.objects.none()
+            queryset = page_class.objects.none()
 
         if parent:
             if getattr(parent, 'navigation_extension', None):
                 # Special case for navigation extensions
-                return list(parent.extended_navigation(depth=depth,
-                    request=context.get('request')))
+                return list(parent.extended_navigation(
+                    depth=depth, request=context.get('request')))
 
             # Apply descendant filter
             queryset &= parent.get_descendants()
@@ -119,16 +127,21 @@ def feincms_nav(context, feincms_page, level=1, depth=1):
                 if getattr(elem, 'navigation_extension', None):
                     current_navextension_node = elem
                     try:
-                        for extended in elem.extended_navigation(depth=depth, request=context.get('request')):
-                            # Only return items from the extended navigation which
-                            # are inside the requested level+depth values. The
-                            # "-1" accounts for the differences in MPTT and
-                            # navigation level counting
-                            this_level = getattr(extended, mptt_opts.level_attr, 0)
+                        for extended in elem.extended_navigation(
+                                depth=depth, request=context.get('request')):
+                            # Only return items from the extended navigation
+                            # which are inside the requested level+depth
+                            # values. The "-1" accounts for the differences in
+                            # MPTT and navigation level counting
+                            this_level = getattr(
+                                extended, mptt_opts.level_attr, 0)
                             if this_level < level + depth - 1:
                                 yield extended
                     except Exception as e:
-                        logger.warn("feincms_nav caught exception in navigation extension for page %d: %s", current_navextension_node.id, format_exception(e))
+                        logger.warn(
+                            "feincms_nav caught exception in navigation"
+                            " extension for page %d: %s",
+                            current_navextension_node.id, format_exception(e))
                 else:
                     current_navextension_node = None
 
@@ -157,7 +170,10 @@ class ParentLinkNode(SimpleNodeWithVarAndArgs):
             return page.get_ancestors()[level - 1].get_absolute_url()
         except IndexError:
             return '#'
-register.tag('feincms_parentlink', do_simple_node_with_var_and_args_helper(ParentLinkNode))
+
+register.tag(
+    'feincms_parentlink',
+    do_simple_node_with_var_and_args_helper(ParentLinkNode))
 
 
 # ------------------------------------------------------------------------
@@ -171,7 +187,8 @@ class LanguageLinksNode(SimpleAssignmentNodeWithVarAndArgs):
 
     Arguments can be any combination of:
 
-    * all or existing: Return all languages or only those where a translation exists
+    * all or existing: Return all languages or only those where a translation
+      exists
     * excludecurrent: Excludes the item in the current language from the list
     * request=request: The current request object, only needed if you are using
       AppContents and need to append the "extra path"
@@ -181,10 +198,11 @@ class LanguageLinksNode(SimpleAssignmentNodeWithVarAndArgs):
 
     Example::
 
-        {% feincms_languagelinks for feincms_page as links all,excludecurrent %}
-        {% for key, name, link in links %}
-            <a href="{% if link %}{{ link }}{% else %}/{{ key }}/{% endif %}">{% trans name %}</a>
-        {% endfor %}
+      {% feincms_languagelinks for feincms_page as links all,excludecurrent %}
+      {% for key, name, link in links %}
+          <a href="{% if link %}{{ link }}{% else %}/{{ key }}/{% endif %}">
+            {% trans name %}</a>
+      {% endfor %}
     """
 
     def what(self, page, args):
@@ -198,9 +216,11 @@ class LanguageLinksNode(SimpleAssignmentNodeWithVarAndArgs):
         request = args.get('request', None)
         if request:
             # Trailing path without first slash
-            trailing_path = request._feincms_extra_context.get('extra_path', '')[1:]
+            trailing_path = request._feincms_extra_context.get(
+                'extra_path', '')[1:]
 
-        translations = dict((t.language, t) for t in page.available_translations())
+        translations = dict(
+            (t.language, t) for t in page.available_translations())
         translations[page.language] = page
 
         links = []
@@ -210,13 +230,18 @@ class LanguageLinksNode(SimpleAssignmentNodeWithVarAndArgs):
 
             # hardcoded paths... bleh
             if key in translations:
-                links.append((key, name,
+                links.append((
+                    key,
+                    name,
                     translations[key].get_absolute_url() + trailing_path))
             elif not only_existing:
                 links.append((key, name, None))
 
         return links
-register.tag('feincms_languagelinks', do_simple_assignment_node_with_var_and_args_helper(LanguageLinksNode))
+
+register.tag(
+    'feincms_languagelinks',
+    do_simple_assignment_node_with_var_and_args_helper(LanguageLinksNode))
 
 
 # ------------------------------------------------------------------------
@@ -224,13 +249,15 @@ def _translate_page_into(page, language, default=None):
     """
     Return the translation for a given page
     """
-    # Optimisation shortcut: No need to dive into translations if page already what we want
+    # Optimisation shortcut: No need to dive into translations if page already
+    # what we want
     try:
         if page.language == language:
             return page
 
         if language is not None:
-            translations = dict((t.language, t) for t in page.available_translations())
+            translations = dict(
+                (t.language, t) for t in page.available_translations())
             if language in translations:
                 return translations[language]
     except AttributeError:
@@ -246,19 +273,21 @@ class TranslatedPageNode(SimpleAssignmentNodeWithVarAndArgs):
     """
     ::
 
-        {% feincms_translatedpage for feincms_page as feincms_transpage language=en %}
+        {% feincms_translatedpage for feincms_page as feincms_transpage
+            language=en %}
         {% feincms_translatedpage for feincms_page as originalpage %}
-        {% feincms_translatedpage for some_page as translatedpage language=feincms_page.language %}
+        {% feincms_translatedpage for some_page as translatedpage
+            language=feincms_page.language %}
 
     This template tag needs the translations extension.
 
     Returns the requested translation of the page if it exists. If the language
-    argument is omitted the primary language will be returned (the first language
-    specified in settings.LANGUAGES).
+    argument is omitted the primary language will be returned (the first
+    language specified in settings.LANGUAGES).
 
-    Note: To distinguish between a bare language code and a variable we check whether
-    settings LANGUAGES contains that code -- so naming a variable "en" will probably
-    not do what is intended.
+    Note: To distinguish between a bare language code and a variable we check
+    whether settings LANGUAGES contains that code -- so naming a variable "en"
+    will probably not do what is intended.
     """
     def what(self, page, args, default=None):
         language = args.get('language', None)
@@ -268,19 +297,29 @@ class TranslatedPageNode(SimpleAssignmentNodeWithVarAndArgs):
         else:
             if language not in (x[0] for x in settings.LANGUAGES):
                 try:
-                    language = template.Variable(language).resolve(self.render_context)
+                    language = template.Variable(language).resolve(
+                        self.render_context)
                 except template.VariableDoesNotExist:
                     language = settings.LANGUAGES[0][0]
 
         return _translate_page_into(page, language, default=default)
-register.tag('feincms_translatedpage', do_simple_assignment_node_with_var_and_args_helper(TranslatedPageNode))
+
+register.tag(
+    'feincms_translatedpage',
+    do_simple_assignment_node_with_var_and_args_helper(TranslatedPageNode))
 
 
 # ------------------------------------------------------------------------
 class TranslatedPageNodeOrBase(TranslatedPageNode):
     def what(self, page, args):
-        return super(TranslatedPageNodeOrBase, self).what(page, args, default=getattr(page, 'get_original_translation', page))
-register.tag('feincms_translatedpage_or_base', do_simple_assignment_node_with_var_and_args_helper(TranslatedPageNodeOrBase))
+        return super(TranslatedPageNodeOrBase, self).what(
+            page, args,
+            default=getattr(page, 'get_original_translation', page))
+
+register.tag(
+    'feincms_translatedpage_or_base',
+    do_simple_assignment_node_with_var_and_args_helper(
+        TranslatedPageNodeOrBase))
 
 
 # ------------------------------------------------------------------------
@@ -289,14 +328,16 @@ def feincms_translated_or_base(pages, language=None):
     if not hasattr(pages, '__iter__'):
         pages = [pages]
     for page in pages:
-        yield _translate_page_into(page, language, default=page.get_original_translation)
+        yield _translate_page_into(
+            page, language, default=page.get_original_translation)
 
 
 # ------------------------------------------------------------------------
 @register.inclusion_tag("breadcrumbs.html")
 def feincms_breadcrumbs(page, include_self=True):
     """
-    Generate a list of the page's ancestors suitable for use as breadcrumb navigation.
+    Generate a list of the page's ancestors suitable for use as breadcrumb
+    navigation.
 
     By default, generates an unordered list with the id "breadcrumbs" -
     override breadcrumbs.html to change this.
@@ -306,9 +347,6 @@ def feincms_breadcrumbs(page, include_self=True):
         {% feincms_breadcrumbs feincms_page %}
     """
 
-    if not page or not isinstance(page, BasePage):
-        raise ValueError("feincms_breadcrumbs must be called with a valid Page object")
-
     ancs = page.get_ancestors()
 
     bc = [(anc.get_absolute_url(), anc.short_title()) for anc in ancs]
@@ -321,7 +359,10 @@ def feincms_breadcrumbs(page, include_self=True):
 
 # ------------------------------------------------------------------------
 def _is_parent_of(page1, page2):
-    return page1.tree_id == page2.tree_id and page1.lft < page2.lft and page1.rght > page2.rght
+    return (
+        page1.tree_id == page2.tree_id
+        and page1.lft < page2.lft
+        and page1.rght > page2.rght)
 
 
 @register.filter
@@ -342,19 +383,25 @@ def is_parent_of(page1, page2):
 
 # ------------------------------------------------------------------------
 def _is_equal_or_parent_of(page1, page2):
-    return page1.tree_id == page2.tree_id and page1.lft <= page2.lft and page1.rght >= page2.rght
+    return (
+        page1.tree_id == page2.tree_id
+        and page1.lft <= page2.lft
+        and page1.rght >= page2.rght)
 
 
 @register.filter
 def is_equal_or_parent_of(page1, page2):
     """
-    Determines whether a given page is equal to or the parent of another
-    page. This is especially handy when generating the navigation. The following
+    Determines whether a given page is equal to or the parent of another page.
+    This is especially handy when generating the navigation. The following
     example adds a CSS class ``current`` to the current main navigation entry::
 
         {% for page in navigation %}
-            <a {% if page|is_equal_or_parent_of:feincms_page %}class="current"{% endif %}>
-                {{ page.title }}</a>
+            <a
+            {% if page|is_equal_or_parent_of:feincms_page %}
+                class="current"
+            {% endif %}
+            >{{ page.title }}</a>
         {% endfor %}
     """
     try:
@@ -405,22 +452,29 @@ def siblings_along_path_to(page_list, page2):
 
     if page_list:
         try:
-            # Try to avoid hitting the database: If the current page is in_navigation,
-            # then all relevant pages are already in the incoming list, no need to
-            # fetch ancestors or children.
+            # Try to avoid hitting the database: If the current page is
+            # in_navigation, then all relevant pages are already in the
+            # incoming list, no need to fetch ancestors or children.
 
-            # NOTE: This assumes that the input list actually is complete (ie. comes from
-            # feincms_nav). We'll cope with the fall-out of that assumption
-            # when it happens...
-            ancestors = [a_page for a_page in page_list
+            # NOTE: This assumes that the input list actually is complete (ie.
+            # comes from feincms_nav). We'll cope with the fall-out of that
+            # assumption when it happens...
+            ancestors = [
+                a_page for a_page in page_list
                 if _is_equal_or_parent_of(a_page, page2)]
             top_level = min((a_page.level for a_page in page_list))
 
             if not ancestors:
-                # Happens when we sit on a page outside the navigation tree
-                # so fake an active root page to avoid a get_ancestors() db call
+                # Happens when we sit on a page outside the navigation tree so
+                # fake an active root page to avoid a get_ancestors() db call
                 # which would only give us a non-navigation root page anyway.
-                p = Page(title="dummy", tree_id=-1, parent_id=None, in_navigation=False)
+                page_class = _get_page_model()
+
+                p = page_class(
+                    title="dummy",
+                    tree_id=-1,
+                    parent_id=None,
+                    in_navigation=False)
                 ancestors = (p,)
 
             siblings = [
@@ -431,8 +485,35 @@ def siblings_along_path_to(page_list, page2):
 
             return siblings
         except (AttributeError, ValueError) as e:
-            logger.warn("siblings_along_path_to caught exception: %s", format_exception(e))
+            logger.warn(
+                "siblings_along_path_to caught exception: %s",
+                format_exception(e))
 
     return ()
 
+
 # ------------------------------------------------------------------------
+@register.assignment_tag(takes_context=True)
+def page_is_active(context, page, feincms_page=None, path=None):
+    """
+    Usage example::
+
+        {% feincms_nav feincms_page level=1 as toplevel %}
+        <ul>
+        {% for page in toplevel %}
+            {% page_is_active page as is_active %}
+            <li {% if is_active %}class="active"{% endif %}>
+                <a href="{{ page.get_navigation_url }}">{{ page.title }}</a>
+            <li>
+        {% endfor %}
+        </ul>
+    """
+    if isinstance(page, PagePretender):
+        if path is None:
+            path = context['request'].path_info
+        return page.get_absolute_url().startswith(path)
+
+    else:
+        if feincms_page is None:
+            feincms_page = context['feincms_page']
+        return _is_equal_or_parent_of(page, feincms_page)
